HashDigest

Struct HashDigest 

pub struct HashDigest<D = Arc<[u8]>> { /* private fields */ }
Hash digest.

Implementations

Source

impl<D> HashDigest<D>
where D: AsRef<[u8]>,

pub fn new(algorithm: HashAlgorithm, raw: D) -> Result<Self, InvalidDigestError>

Create HashDigest from the provided algorithm and raw digest.

Errors

Returns an error if the length of the raw digest does not match the expected size for the algorithm.

pub const fn new_unchecked(algorithm: HashAlgorithm, raw: D) -> Self

Create HashDigest from the provided algorithm and raw digest without checking the digest’s length.

pub const fn algorithm(&self) -> HashAlgorithm

Algorithm used to compute the digest.

pub fn raw(&self) -> &[u8]

Raw digest.

pub fn raw_hex_string(&self) -> String

Convert the raw digest to a hex string.

pub fn into_inner(self) -> D

Convert the digest back to its raw representation.