pub struct HashDigest<D = Arc<[u8]>> { /* private fields */ }Expand description
Hash digest.
Implementations
Sourceimpl<D> HashDigest<D>
impl<D> HashDigest<D>
Sourcepub fn new(algorithm: HashAlgorithm, raw: D) -> Result<Self, InvalidDigestError>
pub fn new(algorithm: HashAlgorithm, raw: D) -> Result<Self, InvalidDigestError>
Create HashDigest from the provided algorithm and raw digest.
Errors
Returns an error if the length of the raw digest does not match the expected size for the algorithm.
Sourcepub const fn new_unchecked(algorithm: HashAlgorithm, raw: D) -> Self
pub const fn new_unchecked(algorithm: HashAlgorithm, raw: D) -> Self
Create HashDigest from the provided algorithm and raw digest without checking
the digest’s length.
Sourcepub const fn algorithm(&self) -> HashAlgorithm
pub const fn algorithm(&self) -> HashAlgorithm
Algorithm used to compute the digest.
Sourcepub fn raw_hex_string(&self) -> String
pub fn raw_hex_string(&self) -> String
Convert the raw digest to a hex string.
Sourcepub fn into_inner(self) -> D
pub fn into_inner(self) -> D
Convert the digest back to its raw representation.